@@ -9,8 +9,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.6',
- 'BLDLIBRARY': '-L. -lpython3.6m',
+ 'BINLIBDEST': '/usr/lib/python3.7',
+ 'BLDLIBRARY': 'libpython3.7m.dll.a',
  'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
  'BUILDEXE': '.exe',
  'BUILDPYTHON': 'python.exe',
@@ -22,13 +22,13 @@ build_time_vars = {'ABIFLAGS': 'm',
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
            '--param=ssp-buffer-size=4 '
-           '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
            '--param=ssp-buffer-size=4 '
-           '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1',
+           '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -37,19 +37,20 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS': '-ggdb -O2 -pipe -Wall -Werror=format-security '
                      '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                      '--param=ssp-buffer-size=4 '
-                     '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-                     '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1',
+                     '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                     '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wno-cast-function-type',
+                            '-Wno-cast-function-type '
+                            '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15' "
+ 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10' "
                 "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
-                "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python36' "
-                "'--htmldir=/usr/share/doc/python36/html' '-C' "
+                "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python37' "
+                "'--htmldir=/usr/share/doc/python37/html' '-C' "
                 "'--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' "
                 "'--with-libc=' '--with-libm=' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
@@ -57,32 +58,32 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security "
                 '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                 '--param=ssp-buffer-size=4 '
-                '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-                "-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1' "
+                '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                "-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1' "
                 "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.6m',
- 'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/build/coverage.info',
- 'COVERAGE_REPORT': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/build/lcov-report',
+ 'CONFINCLUDEPY': '/usr/include/python3.7m',
+ 'COREPYTHONPATH': '',
+ 'COVERAGE_INFO': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/build/coverage.info',
+ 'COVERAGE_REPORT': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15/Include',
+             '-I/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Include',
  'CXX': 'g++',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.6 /usr/lib/python3.6/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.6',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.7 /usr/lib/python3.7/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.7',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.6/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.7/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+ 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+ 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
               'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
- 'DLLLIBRARY': 'libpython3.6m.dll',
+ 'DLLLIBRARY': 'libpython3.7m.dll',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
@@ -95,10 +96,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ENSUREPIP': 'no',
  'EXE': '.exe',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-36m-x86_64-cygwin.dll',
+ 'EXT_SUFFIX': '.cpython-37m-x86_64-cygwin.dll',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -141,6 +141,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
  'HAVE_CRYPT_H': 1,
+ 'HAVE_CRYPT_R': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
  'HAVE_CURSES_FILTER': 1,
@@ -162,6 +163,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
  'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
  'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
@@ -288,6 +290,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LINUX_VM_SOCKETS_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -296,7 +299,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -322,12 +324,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_POSIX_SPAWN': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PREADV': 0,
+ 'HAVE_PREADV2': 0,
  'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 1,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
+ 'HAVE_PTHREAD_GETCPUCLOCKID': 1,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
@@ -335,13 +340,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_PWRITEV': 0,
+ 'HAVE_PWRITEV2': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
@@ -356,7 +362,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
- 'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -382,6 +387,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGINFO_T_SI_BAND': 0,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
  'HAVE_SIGPENDING': 1,
@@ -483,6 +489,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UUID_CREATE': 0,
+ 'HAVE_UUID_ENC_BE': 0,
+ 'HAVE_UUID_GENERATE_TIME_SAFE': 1,
+ 'HAVE_UUID_H': 0,
+ 'HAVE_UUID_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 0,
@@ -494,42 +505,43 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
+ 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-cygwin',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.6m '
-                   '/usr/include/python3.6m',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.7m '
+                   '/usr/include/python3.7m',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.6m',
+ 'INCLUDEPY': '/usr/include/python3.7m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.6m.dll.a',
+ 'INSTSONAME': 'libpython3.7m.dll.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared -Wl,--enable-auto-image-base',
  'LDFLAGS': '',
  'LDFLAGS_NODIST': '',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.6m.dll.a',
+ 'LDLIBRARY': 'libpython3.7m.dll.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
- 'LDVERSION': '3.6m',
+ 'LDVERSION': '3.7m',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.6',
+ 'LIBDEST': '/usr/lib/python3.7',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.6/config-3.6m-x86_64-cygwin',
- 'LIBRARY': 'libpython3.6m.a',
+ 'LIBPL': '/usr/lib/python3.7/config-3.7m-x86_64-cygwin',
+ 'LIBRARY': 'libpython3.7m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lintl -ldl',
+ 'LIBS': '-lcrypt -lintl -ldl',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '',
@@ -541,39 +553,43 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'cygwin',
- 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.6',
+ 'MACHDESTLIB': '/usr/lib/python3.7',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15/Modules/makesetup',
+ 'MAKESETUP': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
+                   '_operator  _collections  _abc  itertools  atexit  _signal  '
+                   '_stat  time  _thread  _locale  _io  zipimport  '
+                   'faulthandler  _tracemalloc  _symtable  xxsubtype',
+ 'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools '
-             '_operator _collections itertools atexit _signal _stat time '
-             '_locale _io zipimport faulthandler _tracemalloc _symtable '
-             'xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  '
-            'Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  '
-            'Modules/_codecsmodule.o  Modules/_weakref.o  '
-            'Modules/_functoolsmodule.o  Modules/_operator.o  '
-            'Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  '
+ 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/_abc.o  Modules/itertoolsmodule.o  '
             'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
-            'Modules/timemodule.o  Modules/_localemodule.o  '
-            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
-            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
-            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/timemodule.o  Modules/_threadmodule.o  '
+            'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
+            'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
+            'Modules/textio.o Modules/stringio.o  Modules/zipimport.o  '
+            'Modules/faulthandler.o  Modules/_tracemalloc.o '
+            'Modules/hashtable.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-cygwin',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-cygwin\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
+ 'OPENSSL_INCLUDES': '',
+ 'OPENSSL_LDFLAGS': '',
+ 'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -589,10 +605,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
- 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 0,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
  'PURIFY': '',
  'PY3LIBRARY': '',
@@ -602,47 +618,89 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':',
+ 'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python.exe -E',
- 'PYTHON_FOR_REGEN': 'python3.6',
+ 'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
+                             '-fwrapv -O3 -Wall -ggdb -O2 -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fstack-protector-strong '
+                             '--param=ssp-buffer-size=4 '
+                             '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
+                             '-ggdb -O2 -pipe -Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+                             '--param=ssp-buffer-size=4 '
+                             '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
+                             '-std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wno-cast-function-type '
+                             '-Werror=implicit-function-declaration -IObjects '
+                             '-IInclude -IPython -I. '
+                             '-I/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Include '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
               '--param=ssp-buffer-size=4 '
-              '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
               '--param=ssp-buffer-size=4 '
-              '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1',
+              '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wno-cast-function-type',
+                     '-Wno-cast-function-type '
+                     '-Werror=implicit-function-declaration',
+ 'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 '
-                   '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
                    '-ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 '
-                   '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/build=/usr/src/debug/python36-3.6.15-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15=/usr/src/debug/python36-3.6.15-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wno-cast-function-type '
-                   '-IObjects -IInclude -IPython -I. '
-                   '-I/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15/Include  '
+                   '-Werror=implicit-function-declaration -IObjects -IInclude '
+                   '-IPython -I. '
+                   '-I/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15/Include',
+                '-I/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
+ 'PY_SSL_DEFAULT_CIPHERS': 1,
+ 'PY_SSL_DEFAULT_CIPHER_STRING': 0,
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
+                        '-O3 -Wall -ggdb -O2 -pipe -Wall '
+                        '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                        '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
+                        '-ggdb -O2 -pipe -Wall -Werror=format-security '
+                        '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+                        '--param=ssp-buffer-size=4 '
+                        '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/build=/usr/src/debug/python37-3.7.10-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10=/usr/src/debug/python37-3.7.10-1 '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wno-cast-function-type '
+                        '-Werror=implicit-function-declaration -IObjects '
+                        '-IInclude -IPython -I. '
+                        '-I/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -653,9 +711,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'RUNSHARED': '',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '',
+ 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lintl -ldl',
+ 'SHLIBS': '-lcrypt -lintl -ldl',
  'SHLIB_SUFFIX': '.dll',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -668,6 +726,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
+ 'SIZEOF_PTHREAD_KEY_T': 8,
  'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 8,
@@ -676,9 +735,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 2,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36m-x86_64-cygwin',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
- 'SRC_GDB_HOOKS': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15/Tools/gdb/libpython.py',
+ 'SOABI': 'cpython-37m-x86_64-cygwin',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SRC_GDB_HOOKS': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -694,35 +753,32 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python.exe '
-               '/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15/Tools/scripts/run_tests.py',
+               '/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
- 'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.6 '
-                '/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.7 '
+                '/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'USE_INLINE': 1,
- 'VERSION': '3.6',
- 'VPATH': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15',
- 'WANT_SIGFPE_HANDLER': 0,
+ 'VERSION': '3.7',
+ 'VPATH': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10',
  'WINDOW_HAS_FLAGS': 0,
+ 'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
- 'WITH_THREAD': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/build',
- 'abs_srcdir': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15',
+ 'abs_builddir': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/build',
+ 'abs_srcdir': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/pub/devel/python/python36/python36-3.6.15-1.x86_64/src/Python-3.6.15'}
+ 'srcdir': '/pub/devel/python/python37/python37-3.7.10-1.x86_64/src/Python-3.7.10'}
